package Acme::Playpen;

use strict;
use warnings;
use 5.006;

use Acme::Playpen::Utilities;

package Acme::odometer;

1;

=head1 NAME

Acme::Playpen - a test distribution for playing around

=head1 DESCRIPTION

In the beginning the Universe was created.
This has made a lot of people very angry and been widely regarded as a bad move.

=head1 LICENSE AND COPYRIGHT

This software is copyright (c) 2013 by Neil Bowers <neilb@cpan.org>.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

